@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 #from win32com.shell import shell, shellcon
 from logging import exception
+import asyncio
 import os
 import io
 import traceback
@@ -15,13 +16,13 @@ import platform
 import re
 import base64
 
-import asyncio
 import websockets
 import paramiko
 import win32gui
 from win32com.shell import shell, shellcon
 #import Xlib.support.connect as xlib_connect
 
+api_version = '3.1.1.0'
 
 try:
     from lang import *
@@ -283,7 +284,7 @@ fi
         if not slurm_exist: (pbs_exist,   queue_info) = check_if_pbs_exist(client)
         if check_queue:
             queue_type   = "slurm" if slurm_exist else ("pbs" if pbs_exist else "none")
-            print("return queue check info", queue_type, queue_info)
+            #print("return queue check info", queue_type, queue_info)
             await websocket.send( json.dumps({
                 "name"         : "submit-task",
                 "ckey"         : ckey,
@@ -501,8 +502,8 @@ sinfo
     stdout.channel.recv_exit_status()
     out = (stdout.read() or b"").decode()
     err = (stderr.read() or b"").decode()
-    print("check if_slurm_exist out=", out)
-    print("check if_slurm_exist err=", err)
+    #print("check if_slurm_exist out=", out)
+    #print("check if_slurm_exist err=", err)
     if err: return (False,'')
     out = out.split("#-queue-out-#\n")[1]
     return (True,out)
@@ -543,7 +544,7 @@ async def stop_task(config, ckey, message, websocket):
     client      = conn['client']
     #print("try stop with :", running_mode)
     if running_mode == 'slurm':
-        print("check slurm task: {0}_{1}".format(task_uid, batch) )
+        #print("check slurm task: {0}_{1}".format(task_uid, batch) )
         if check_if_slurm_exist(client)[0]:
             #print("check slurm task:", task_uid)
             stdin, stdout, stderr = client.exec_command("""
@@ -559,7 +560,7 @@ fi
             stdout.channel.recv_exit_status()
             out  = (stdout.read() or b"").decode()
             err  = (stderr.read() or b"").decode()
-            print("task killed")
+            #print("task killed")
             pass
         else:
             #print("pbs task kill, but no pbs command found" )
@@ -573,10 +574,10 @@ fi
             stdout.channel.recv_exit_status()
             out  = (stdout.read() or b"").decode()
             err  = (stderr.read() or b"").decode()
-            print("task already vanished")
+            #print("task already vanished")
             pass
     elif running_mode == 'pbs':
-        print("check pbs task: {0}_{1}".format(task_uid, batch) )
+        #print("check pbs task: {0}_{1}".format(task_uid, batch) )
         if check_if_pbs_exist(client)[0]:
             #print("check pbs task:", task_uid)
             stdin, stdout, stderr = client.exec_command("""
@@ -592,7 +593,7 @@ fi
             stdout.channel.recv_exit_status()
             out  = (stdout.read() or b"").decode()
             err  = (stderr.read() or b"").decode()
-            print("task killed")
+            #print("task killed")
             pass
         else:
             #print("pbs task kill, but no pbs command found" )
@@ -606,11 +607,11 @@ fi
             stdout.channel.recv_exit_status()
             out  = (stdout.read() or b"").decode()
             err  = (stderr.read() or b"").decode()
-            print("task already vanished")
+            #print("task already vanished")
             pass
         pass
     else:
-        print("check no pbs task: {0}_{1}".format(task_uid, batch), flush=True)
+        #print("check no pbs task: {0}_{1}".format(task_uid, batch), flush=True)
         stdin, stdout, stderr = client.exec_command("""
 cd ~/pond-calculation-works/{2}/.tasks/
 pid=`ps -ef|grep ./.tasks/{0}_{1}|grep code` 
@@ -626,10 +627,10 @@ fi
         stdout.channel.recv_exit_status()
         out  = (stdout.read() or b"").decode()
         err  = (stderr.read() or b"").decode()
-        print("task killed",flush=True)
+        #print("task killed",flush=True)
         pass
-    print("kill out >>>", out, sep='')
-    print("kill err >>>", err, sep='')
+    #print("kill out >>>", out, sep='')
+    #print("kill err >>>", err, sep='')
     await websocket.send( json.dumps({
         "name"   : "check-task",
         "info"   : "task-stoped",
@@ -648,6 +649,7 @@ async def check_task(config, ckey, message, websocket):
     task_uid        = task_options.get("uid")
     current_batch   = message.get("current_batch")
     batches         = message.get("batches")
+    running_mode    = message.get("running_mode")
 
     #print("try check with:", current_batch, start_len )
 
@@ -671,7 +673,7 @@ async def check_task(config, ckey, message, websocket):
         TASK_CHECKING[ ckey+"_"+task_uid ] = True
         pass
 
-    #print('check evaluating batches:', batches, current_batch)
+    print('check evaluating batches:', batches, current_batch, start_len)
     batch_result   = []
     output_result  = ""
     error_result  = ""
@@ -681,7 +683,32 @@ async def check_task(config, ckey, message, websocket):
     echo "#-TASK_INFO_START-#"
     if [ -f {0}.log ]; then
         if [ -f {0}.pid ]; then
-            echo "evaluating"
+            pid=`cat {0}.pid |awk '{{print $NF}}'`
+            if [ {3} == 'slurm' ]; then
+                jobid=`cat {0}.pid |awk '{{print $NF}}'`
+                jobstate=`squeue --j ${{jobid}} -o "%t"|tail -1`
+                if [ ${{jobstate}} == 'PD' ]; then
+                    echo "queueing"
+                elif [ ${{jobstate}} == 'R' ]; then
+                    echo "evaluating"
+                elif [ ${{jobstate}} == 'C' ]; then
+                    echo "finished"
+                else 
+                    echo ${{jobstate}}
+                fi
+            elif [ {3} == 'pbs' ]; then
+                jobid=`cat {0}.pid`
+                jobstate=`qstat -f ${{jobid}} |grep 'job_state'|awk '{{print $NF}}'`
+                if [ ${{jobstate}} == "Q" ]; then
+                    echo "queueing"
+                elif [ ${{jobstate}} == "R" ]; then
+                    echo "evaluating"
+                else 
+                    echo ${{jobstate}}
+                fi
+            else
+                echo "evaluating"
+            fi
         else
             echo "finished"
         fi
@@ -694,10 +721,13 @@ async def check_task(config, ckey, message, websocket):
         echo `cat {0}.time`
     fi
     echo "#-TASK_INFO_END-#"
-    out=`cat {0}.log`
-    echo -n "${{out:{2}}}"
+    if [ {4} ]; then
+        out=`cat {0}.log`
+        echo -n "${{out:{2}}}"
+    fi
         """.format(
             task_uid+"_"+batch, ckey, start_len,
+            running_mode, 'true' if current_batch == batch else '',
         ))
         stdin.channel.shutdown_write()
         stdout.channel.recv_exit_status()
@@ -713,9 +743,9 @@ async def check_task(config, ckey, message, websocket):
             output_result  = output
             error_result   = err
         pass
-    #print("get batch result:", batch_result, )
-    #print("output result = ", output_result)
-    #print("error result = ", error_result)
+    print("get batch result:", batch_result, )
+    print("output result = ", output_result)
+    print("error result = ", error_result)
 
     await websocket.send( json.dumps({
         "name"            : "check-task",
@@ -1082,6 +1112,7 @@ def sftp_listdir(infos, ckey, sftp, message):
             "dirs"         : dirs,  
             'md5'          : new_md5,
             'current_dir'  : current_dir,  
+            'remote_path'  : infos['remote_path'],
         }
         INFO['is_sftp_processing']  = False
         return result
@@ -1332,6 +1363,11 @@ async def data_processing(websocket, data):
 
         WEBSOCKETS[page_id]     = websocket
 
+        await websocket.send(json.dumps({
+            'name'         : 'api_version',
+            'api_version'  : api_version,
+        }))
+
         #print('\nget input request', message_type, ckey, page_id )
         if message_name  == "test-ssh-connection":
             await test_ssh_connection(websocket, config)
